@@ -54,6 +54,7 @@ export default class ImageInput extends React.Component {
     img.src = this.props.current
     img.onload = () => {
       let imgdim = { width: img.width, height: img.height }
+      console.log(imgdim)
       const smallest = (imgdim.width < imgdim.height) ? imgdim.width : imgdim.height
       this.refs.scaleSlider.value = 0
 
@@ -79,10 +80,13 @@ export default class ImageInput extends React.Component {
   }
 
   onFileChosen(e) {
-    this.setState({ editorMsg: 'loading...', hasImg: true })
-
     const fileInput = this.refs.fileInput
     var file = fileInput.files[0]
+    if (!file)
+      return
+
+    this.setState({ editorMsg: 'loading...', hasImg: true })
+
     var reader = new FileReader()
     reader.onload = e => {
       const img = document.createElement('img')
@@ -91,6 +95,10 @@ export default class ImageInput extends React.Component {
       const imgdim = { width: img.width, height: img.height }
       const smallest = (imgdim.width < imgdim.height) ? imgdim.width : imgdim.height
       this.refs.scaleSlider.value = 0
+
+      if (this.props.onChange)
+        this.props.onChange()
+
       this.setState({
         img: img,
         imgdim: imgdim,
@@ -124,6 +132,7 @@ export default class ImageInput extends React.Component {
   onCanvasMouseMove (e) {
     e.preventDefault()
     if (this.state.dragging) {
+      console.log('ox+clientX-mx',this.state.ox + e.clientX - this.state.mx, '-width', -this.state.imgdim.width, 'zoom', this.state.zoom, '-width*zoom+canvas', -this.state.imgdim.width * this.state.zoom + CANVAS_SIZE)
       this.setState({
         ox: Math.max(Math.min(this.state.ox + e.clientX - this.state.mx, 0), -this.state.imgdim.width * this.state.zoom + CANVAS_SIZE),
         oy: Math.max(Math.min(this.state.oy + e.clientY - this.state.my, 0), -this.state.imgdim.height * this.state.zoom + CANVAS_SIZE),
@@ -153,40 +162,37 @@ export default class ImageInput extends React.Component {
  
     ctx.fillStyle = '#fff'
     ctx.fillRect(0, 0, canvas.width, canvas.height)
-		ctx.save()
+    // ctx.drawImage(this.state.img, this.state.ox, this.state.oy, this.state.img.width * this.state.zoom, this.state.img.height * this.state.zoom)
 
-    ctx.scale(this.state.zoom, this.state.zoom)
+    ctx.save()
+
+    // rotate from center
+    // TODO Im disabling this for now because it's broken, and I dont have time to fix it atm -prf
+    // ctx.translate(CANVAS_SIZE/2, CANVAS_SIZE/2)
+    // ctx.rotate(this.state.rotation/2 * Math.PI)
+    // ctx.translate(-CANVAS_SIZE/2, -CANVAS_SIZE/2)
+    
     ctx.translate(this.state.ox, this.state.oy)
-  	ctx.translate(this.state.img.width/2, this.state.img.height/2)
-		ctx.rotate(this.state.rotation/2 * Math.PI)
-		ctx.drawImage(
-      this.state.img, 
-      -this.state.img.width/2, -this.state.img.height/2,
-      this.state.img.width, this.state.img.height
-    )
-		ctx.restore()
+    ctx.scale(this.state.zoom, this.state.zoom)
+    ctx.drawImage(this.state.img, 0, 0, this.state.img.width, this.state.img.height)
+
+    ctx.restore()
   }
 
   render() {
     return <div className="image-input">
-      <div>
-        <label>
-          <span>{this.props.label}</span>
-          <input ref="fileInput" type="file" accept="image/png,image/jpg,image/jpeg" onChange={this.onFileChosen.bind(this)} style={{display: 'none'}} />
-          <button className="btn" onClick={this.onClickFile.bind(this)}>Choose File</button>
-        </label>
-      </div>
       { this.state.hasImg ? 
         <div className="image-input-ctrls">
-          <div className="flex" style={{color: 'gray', alignItems: 'center'}}>
-            <div style={{whiteSpace: 'pre', paddingRight: '15px'}}>
-              <label>Rotation: <button className="btn" onClick={this.onRotate.bind(this)}>{(this.state.rotation*90)+' degrees'}</button></label>
-            </div>
+          <div className="inline-flex" style={{color: 'gray', alignItems: 'center'}}>
             <div style={{flex: 1, paddingRight: '5px'}}>
               { this.state.editorMsg ? <div>{this.state.editorMsg}</div> : '' }
               <input ref="scaleSlider" type="range" value={this.state.scaleSliderValue} onChange={this.onResize.bind(this)} style={{height: '45px', verticalAlign: 'middle'}} />
             </div>
+            {''/*<div style={{whiteSpace: 'pre', paddingLeft: '15px'}}>
+              <label>Rotate: <button className="btn" onClick={this.onRotate.bind(this)} style={{padding: '10px 16px', color: 'gray'}}><i className="fa fa-rotate-right" /></button></label>
+            </div>*/}
           </div>
+          <br/>
           <canvas ref="canvas" width={CANVAS_SIZE} height={CANVAS_SIZE}
             onMouseDown={this.onCanvasMouseDown.bind(this)}
             onMouseUp={this.onCanvasMouseUp.bind(this)}
@@ -194,6 +200,13 @@ export default class ImageInput extends React.Component {
             onMouseMove={this.onCanvasMouseMove.bind(this)} />
         </div>
         : '' }
+      <div>
+        <label>
+          <span>{this.props.label}</span>
+          <input ref="fileInput" type="file" accept="image/png,image/jpg,image/jpeg" onChange={this.onFileChosen.bind(this)} style={{display: 'none'}} />
+          <button className="btn" onClick={this.onClickFile.bind(this)}>Choose File</button>
+        </label>
+      </div>
     </div>
   }
 
