@@ -15,7 +15,7 @@ class Tab extends React.Component {
 
 export default class Tabs extends React.Component {
   render() {
-    return <div className={'tabs'+(this.props.vertical?' vertical':'')}>
+    return <div className={`tabs ${this.props.vertical?'vertical':''} ${this.props.className||''}`}>
       {this.props.options.map((opt,i) => <Tab key={i} useIcon={!!this.props.vertical} option={opt} selected={opt === this.props.selected} onClick={this.props.onSelect} />)}
     </div>
   }
