@@ -1,7 +1,7 @@
 // setup basic error-handling, in case app fails to load
 
 window.loadErrorHandler = function (e) {
-  console.error(e.error)
+  console.error(e.error || e)
 
   // render heading
   var h1 = document.createElement('h1')
@@ -14,7 +14,7 @@ window.loadErrorHandler = function (e) {
   pre.style.margin = '10px'
   pre.style.padding = '10px'
   pre.style.boxShadow = '0 2px 4px rgba(0,0,0,0.1)'
-  pre.innerText = e.error.stack || e.error.toString()
+  pre.innerText = e.error ? (e.error.stack || e.error.toString()) : e.message
   document.body.appendChild(pre)
 }
 window.addEventListener('error', window.loadErrorHandler)
\ No newline at end of file
