@@ -1,5 +1,7 @@
 'use babel'
 import React from 'react'
+import LeftNav from '../com/leftnav'
+import RightNav from '../com/rightnav'
 import MsgList from '../com/msg-list'
 import Card from '../com/msg-view/card'
 import app from '../lib/app'
@@ -12,13 +14,15 @@ export default class Search extends React.Component {
 
   render() {
     const searchRegex = new RegExp(this.props.params.query||'', 'i')
-    const Hero = (props) => <h2 style={{fontWeight: 300, textAlign: 'center'}}>Searching for "{this.props.params.query}"</h2>
     return <div id="search" key={this.props.params.query}>
       <MsgList
         ref="list"
+        searchQuery={this.props.params.query}
         searchRegex={searchRegex}
+        composerProps={{ isPublic: true }}
+        LeftNav={LeftNav} leftNavProps={{location: this.props.location}}
+        RightNav={RightNav}
         dateDividers
-        Hero={Hero}
         ListItem={Card}
         live={{ gt: [Date.now(), null] }}
         emptyMsg="No results found."
